Wrap-up and Acknowledgements — Django: Sane Testing v0.4.0 documentation

### Navigation

- index
- previous |
- Django: Sane Testing v0.4.0 documentation »

# Wrap-up and Acknowledgements

I hope this library will be useful for minority I belong to. If you have some ideas for testing that you’d like to use with Django (like Windmill integration), don’t hesistate to write me (bugs at almad.net), so I know what is wanted (and used) and hopefully, you’ll se it implemented.

At last, but not at least, I’d like to send thanks & kudos to:

- Mikeal Rogers for a lot of ideas and implementation. Lot of his code is reused in this library (see attributions in code)
- CherryPy team for their excellent WSGI implementation (and nice framework)
- Jason Pellerin for nose library we’re building on
- Django authors and contributors for Django itself.

### Navigation

- index
- previous |
- Django: Sane Testing v0.4.0 documentation »